@@ -57,7 +57,6 @@ class MyBarLogger(ProgressBarLogger):
 
 def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, time_o=5):
     outro_sound = MusicHelper.create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat)
-
     path_video = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid-audio.mp4")
     tmp_path_composite_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-comp-outro-lyric-vid.mp4")
     tmp_clip = CompositeVideoClip(arr_comp).subclip(0, time_o)
@@ -99,7 +98,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     #check if videos are compilation
     for comp in arr_comps:
         if indexVidBG < 5 and  (comp.type == "video" or comp.type == "image"):
-            firstImageOrVideoBG.append(comp)
+            firstImageOrVideoBG.append(comp.make())
             indexVidBG+=1
 
         if comp.type == "lyric":
@@ -169,6 +168,8 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             item.set_start(tmp_start)
     logger = MyBarLogger(job_id, mf_server)
     if not is_compilation:
+        if max_duration <= 0:
+            max_duration = max_real_duration
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_duration)
         final_clip.write_videofile(path_video, bitrate='4M', fps=24, codec='libx264', logger=logger)
         final_clip.close()
@@ -500,7 +501,7 @@ class VideoComp(Component):
         if self.is_canva:
             self.kind = "canva"
     def get_clip(self):
-        if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro:
+        if self.isLoop and self.isSmoothLoop and self.ext != "gif" and not self.is_intro and not self.is_outro and self.md5!="tiktok":
             obj = requests.get(self.mf_server+"resource/get-md5/"+self.kind+"/"+self.md5).json()
             if "id" in obj:
                 if "loop_link" in obj and obj['loop_link'] is not None and "gdrive" in obj['loop_link']:
